; ##############################################################################
; ##############################################################################
; ##############################################################################
; SCRATCHPAD auslesen, nur ein SLAVE vorhanden !								
;																				
; OUT: CARRY, SRAM (adr_SCRATCHPAD_CRC_BEREICH)									
;																				
DSXXXX_SPEZAIAL_SCRATCHPAD_READ:
	; CLEAR												
	rcall DSXXXX_SCRATCHPAD_CLEAR
	; RESET												
	rcall ONE_WIRE_RESET_PRESENCE				; OUT: CARRY		
	brcc DSXXXX_SPEZAIAL_SCRATCHPAD_READ_ERROR	; CARRY=0 ==> SPRUNG		
	; MASTER TX xCC (SKIP ROM)							
	ldi	temp1,0xCC
	rcall ONE_WIRE_DATA_WRITE
	; MASTER TX xBE (read SCRATCHPAD)					
	rcall DSXXXX_SCRATCHPAD_READ_SINGLE_MARKE	; OUT: (CRC)				
	brcc DSXXXX_SPEZAIAL_SCRATCHPAD_READ_ERROR	; CARRY=0 ==> SPRUNG		
	; CARRY setzen			
	SEC
	ret
;----------------------------------------------------------------------------------
DSXXXX_SPEZAIAL_SCRATCHPAD_READ_ERROR:
	; ERROR					
	ldi temp,(ERROR_SINGLE_SCRATCHPAD_READ)	; CODE				
	rcall ERROR_SPEICHERN					; inp temp (CODE)	
	; CARRY clear			
	CLC
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; nur ein SLAVE am BUS, ROM + SCRATCHPAD auslesen und TEMPERATUREN berechnen	
;																				
; OUT: SRAM	(adr_TEMPERATURTEMPERATURWERTE)										
;																				
DSXXXX_SPEZAIAL_ROM_SCRATCHPAD_READ:
	; CLEAR										
	rcall DSXXXX_TEMPERATURTEMPERATURWERTE_CLEAR
	rcall ROM_CLEAR
	rcall DSXXXX_SCRATCHPAD_CLEAR
	; ROM (SINGLE)								
	rcall ROM_READ									; OUT: (CARRY)				
	brcc DSXXXX_SPEZAIAL_ROM_SCRATCHPAD_READ_ERROR	; CARRY=0 ==> SPRUNG		
	; SCRATCHPAD+TEMPERATUR						
	rcall DSXXXX_SCRATCHPAD_TEMPERATURBERECHNUNG	; OUT: CARRY		
	brcc DSXXXX_SPEZAIAL_ROM_SCRATCHPAD_READ_ERROR	; CARRY=0 ==> SPRUNG		
	; CARRY setzen								
	SEC	
	ret
;----------------------------------------------------------------------------------
DSXXXX_SPEZAIAL_ROM_SCRATCHPAD_READ_ERROR:
	; ERROR					
	ldi temp,(ERROR_SINGLE_MESSEN)	; CODE				
	rcall ERROR_SPEICHERN			; inp temp (CODE)	
	; CARRY clear			
	CLC
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; mehrere SLAVE am BUS, ein Slave direkt ansprechen, SCRATCHPAD auslesen 		
; und Temperatur berechnen														
;																				
; INP: SRAM (adr_ROM_CRC_BEREICH)												
; OUT: SRAM	(adr_TEMPERATURTEMPERATURWERTE)										
;																				
DSXXXX_SPEZAIAL_SCRATCHPAD_DIREKT:
	; CLEAR						
	rcall DSXXXX_SCRATCHPAD_CLEAR
	; ROM CRC					
	rcall ONE_WIRE_ROM_CRC7							; OUT: CARRY		
	brcc DSXXXX_SPEZAIAL_SCRATCHPAD_DIREKT_ERROR	; CARRY=0 ==> SPRUNG
	; SCRATCHPAD+TEMPERATUR		
	rcall DSXXXX_SCRATCHPAD_TEMPERATURBERECHNUNG	; OUT: CARRY		
	brcc DSXXXX_SPEZAIAL_SCRATCHPAD_DIREKT_ERROR	; CARRY=0 ==> SPRUNG
	; CARRY setzen				
	SEC	
	ret
;-------------------------------------------------------------------------------
DSXXXX_SPEZAIAL_SCRATCHPAD_DIREKT_ERROR:
	; ERROR						
	ldi temp,(ERROR_DIREKT_MESSEN)	; CODE				
	rcall ERROR_SPEICHERN			; inp temp (CODE)	
	; CARRY clear				
	CLC
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
;  nur ein SLAVE vorhanden !													
;																				
; EEPROM ins SCRATCHPAD , vorsicht, alle Sensoren knnen hiermit gleichzeitig	
; beschrieben werden															
;																				
DSXXXX_SPEZAIAL_COPPY_EEPROM_SCRATCHPAD:
	; RESET										
	rcall ONE_WIRE_RESET_PRESENCE
	; MASTER TX xCC (SKIP ROM)					
	ldi	temp1,0xCC
	rcall ONE_WIRE_DATA_WRITE
	; MASTER TX xB8 (COPPY EEPROM in SCRATCHPAD)
	ldi	temp1,0xB8			
	rcall ONE_WIRE_DATA_WRITE
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; nur ein SLAVE vorhanden !														
;																				
; SCRATCHPAD ins EEPROM , vorsicht, alle Sensoren knnen hiermit gleichzeitig	
; beschrieben werden															
;																				
DSXXXX_SPEZAIAL_COPPY_SCRATCHPAD_EEPROM:
	; RESET										
	rcall ONE_WIRE_RESET_PRESENCE
	; MASTER TX xCC (SKIP ROM)					
	ldi	temp1,0xCC
	rcall ONE_WIRE_DATA_WRITE
	; MASTER TX x48 (COPPY SCRATCHPAD in EEPROM)
	ldi	temp1,0x48			
	rcall ONE_WIRE_DATA_WRITE
	; voll POWER (strong pullup )				
	sbi (ONE_WIRE_PORT),(ONE_WIRE_PORTBIT)	; HIGH-PEGEL 	
	sbi (ONE_WIRE_DDR), (ONE_WIRE_PORTBIT)	; AUF AUSGANG	
	; Pause 									
	rcall WAIT_1s
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
